summaryrefslogtreecommitdiffstats
path: root/twin/clients/b2/b2client.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'twin/clients/b2/b2client.cpp')
-rw-r--r--twin/clients/b2/b2client.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/twin/clients/b2/b2client.cpp b/twin/clients/b2/b2client.cpp
index 28ebc9c76..8e62360a6 100644
--- a/twin/clients/b2/b2client.cpp
+++ b/twin/clients/b2/b2client.cpp
@@ -558,7 +558,7 @@ bool B2Client::mustDrawHandle() const
void B2Client::iconChange()
{
if (button[BtnMenu])
- button[BtnMenu]->tqrepaint(false);
+ button[BtnMenu]->repaint(false);
}
// Gallium: New button show/hide magic for customizable
@@ -607,7 +607,7 @@ void B2Client::resizeEvent(TQResizeEvent * /*e*/)
titleMoveAbs(bar_x_ofs);
doShape();
- widget()->tqrepaint(); // the frame is misrendered without this
+ widget()->repaint(); // the frame is misrendered without this
}
void B2Client::captionChange()
@@ -616,7 +616,7 @@ void B2Client::captionChange()
titleMoveAbs(bar_x_ofs);
doShape();
titlebar->recalcBuffer();
- titlebar->tqrepaint(false);
+ titlebar->repaint(false);
}
void B2Client::paintEvent(TQPaintEvent* e)
@@ -710,7 +710,7 @@ void B2Client::paintEvent(TQPaintEvent* e)
visibilitinotify events until its state changes, so we just try
*/
if (titlebar->isFullyObscured()) {
/* We first see, if our tqrepaint contained the titlebar area */
TQRegion reg(TQRect(0, 0, width(), buttonSize + 4));
reg = reg.intersect(e->region());
if (!reg.isEmpty())
@@ -815,8 +815,8 @@ void B2Client::titleMoveAbs(int new_ofs)
bar_x_ofs = new_ofs;
positionButtons();
doShape();
- widget()->tqrepaint(0, 0, width(), buttonSize + 4, false);
- titlebar->tqrepaint(false);
+ widget()->repaint(0, 0, width(), buttonSize + 4, false);
+ titlebar->repaint(false);
}
}
@@ -841,7 +841,7 @@ void B2Client::maximizeChange()
bool m = maximizeMode() == MaximizeFull;
if (button[BtnMax]) {
button[BtnMax]->setPixmaps(m ? P_NORMALIZE : P_MAX);
- button[BtnMax]->tqrepaint();
+ button[BtnMax]->repaint();
TQToolTip::remove(button[BtnMax]);
TQToolTip::add(button[BtnMax],
m ? i18n("Restore") : i18n("Maximize"));
@@ -851,13 +851,13 @@ void B2Client::maximizeChange()
g->activate();
doShape();
- widget()->tqrepaint(false);
+ widget()->repaint(false);
}
void B2Client::activeChange()
{
- widget()->tqrepaint(false);
- titlebar->tqrepaint(false);
+ widget()->repaint(false);
+ titlebar->repaint(false);
TQColor c = options()->colorGroup(
KDecoration::ColorTitleBar, isActive()).color(TQColorGroup::Button);
@@ -865,7 +865,7 @@ void B2Client::activeChange()
for (int i = 0; i < BtnCount; i++)
if (button[i]) {
button[i]->setBg(c);
- button[i]->tqrepaint(false);
+ button[i]->repaint(false);
}
}
@@ -1128,7 +1128,7 @@ void B2Client::positionButtons()
// Transparent bound stuff.
static TQRect *visible_bound;
-static TQPointArray bound_tqshape;
+static TQPointArray bound_shape;
bool B2Client::drawbound(const TQRect& geom, bool clear)
{
@@ -1153,7 +1153,7 @@ bool B2Client::drawbound(const TQRect& geom, bool clear)
barLeft += 2;
barRight -= 2;
- bound_tqshape.putPoints(0, 8,
+ bound_shape.putPoints(0, 8,
g.left(), frameTop,
barLeft, frameTop,
barLeft, g.top(),
@@ -1168,7 +1168,7 @@ bool B2Client::drawbound(const TQRect& geom, bool clear)
TQPainter p(workspaceWidget());
p.setPen(TQPen(Qt::white, 5));
p.setRasterOp(TQt::XorROP);
- p.drawPolygon(bound_tqshape);
+ p.drawPolygon(bound_shape);
if (clear) {
delete visible_bound;
@@ -1273,7 +1273,7 @@ void B2Button::setPixmaps(int button_id)
for (int i = 0; i < NumStates; i++) {
icon[i] = B2::pixmap[button_id + i];
}
- tqrepaint(false);
+ repaint(false);
}
void B2Button::mousePressEvent(TQMouseEvent * e)
@@ -1297,14 +1297,14 @@ void B2Button::mouseReleaseEvent(TQMouseEvent * e)
void B2Button::enterEvent(TQEvent *e)
{
hover = true;
- tqrepaint(false);
+ repaint(false);
TQButton::enterEvent(e);
}
void B2Button::leaveEvent(TQEvent *e)
{
hover = false;
- tqrepaint(false);
+ repaint(false);
TQButton::leaveEvent(e);
}
@@ -1388,7 +1388,7 @@ void B2Titlebar::recalcBuffer()
void B2Titlebar::resizeEvent(TQResizeEvent *)
{
recalcBuffer();
- tqrepaint(false);
+ repaint(false);
}
@@ -710,7 +710,7 @@ void B2Client::paintEvent(TQPaintEvent* e)
*/
if (titlebar->isFullyObscured()) {
- /* We first see, if our tqrepaint contained the titlebar area */
+ /* We first see, if our repaint contained the titlebar area */
TQRegion reg(TQRect(0, 0, width(), buttonSize + 4));
reg = reg.intersect(e->region());